@@ -46,7 +46,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return @ref QModelIndex with the index of the item.
          */
-        QModelIndex index(int row, int column, const QModelIndex & parent = QModelIndex()) const;
+        QModelIndex index(int row, int column, const QModelIndex & parent = QModelIndex()) const override;
 
         /**
          * Returns the number of rows.
@@ -54,7 +54,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return the number of rows.
          */
-        int rowCount(const QModelIndex &parent = QModelIndex()) const;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
         /**
          * Returns the number of columns.
@@ -62,7 +62,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return the number of columns.
          */
-        int columnCount(const QModelIndex &parent = QModelIndex()) const;
+        int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
         /**
          * Returns the data stored under the given role for the item referred to by the index.
@@ -71,7 +71,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return the specified data.
          */
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
         /**
          * Sets the role data for the item at index to value.
@@ -81,7 +81,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return if successful true, otherwise false.
          */
-        bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
+        bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
         /**
          * Returns the data for the given role and section in the header with the specified orientation.
@@ -91,7 +91,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return the specified data.
          */
-        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
         /**
          * inserts rows into the model before the given one.
@@ -102,7 +102,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return true if the rows were successfully inserted, otherwise false.
          */
-        bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex());
+        bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
 
         /**
          * removes rows from the model, starting with the given row.
@@ -112,7 +112,7 @@ class TeaListModel : public QAbstractTableModel
          *
          * @return true if the rows were successfully removed, otherwise false.
          */
-        bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
+        bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
 
         /**
          * Returns the whole list of teas.
